import 'package:fc_components/util/adapt.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class FcNavigationBar extends StatefulWidget {
  const FcNavigationBar({
    Key? key,
    required this.items,
    this.selectedItemColor,
    this.unselectedItemColor,
    this.onTap,
  }) : super(key: key);

  /// 导航元素
  final List<FcNavigationBarItem> items;

  /// 选中元素颜色
  final Color? selectedItemColor;

  /// 未选中元素颜色
  final Color? unselectedItemColor;

  /// 点击回调
  final void Function(dynamic name)? onTap;

  @override
  _FcNavigationBarState createState() => _FcNavigationBarState();
}

class _FcNavigationBarState extends State<FcNavigationBar> {
  dynamic activeItem;

  @override
  void initState() {
    super.initState();

    /// 初始化默认导航元素
    if (widget.items[0].name != null) {
      activeItem = widget.items[0].name;
    } else {
      activeItem = 0;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(bottom: MediaQuery.of(context).padding.bottom),
      decoration: BoxDecoration(
        border: Border(
          top: BorderSide(
            color: const Color(0xFF000000).withOpacity(0.1),
            width: Adapt.px(1),
          ),
        ),
      ),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        children: List.generate(widget.items.length, (int index) {
          return _FcNavigationBarTile(
            widget.items[index],
            index: index,
            selectedIcon: activeItem,
            selectedItemColor:
                widget.selectedItemColor ?? const Color(0xFFD4052D),
            unselectedItemColor:
                widget.unselectedItemColor ?? const Color(0xFF333333),
            onTap: (dynamic name) {
              setState(() {
                activeItem = name;
              });

              if (widget.onTap != null) {
                widget.onTap!(activeItem);
              }
            },
          );
        }),
      ),
    );
  }
}

/// navbar元素
class _FcNavigationBarTile extends StatelessWidget {
  const _FcNavigationBarTile(
    this.info, {
    Key? key,
    required this.index,
    required this.selectedIcon,
    required this.onTap,
    required this.selectedItemColor,
    required this.unselectedItemColor,
  }) : super(key: key);

  /// navbar元素数据信息
  final FcNavigationBarItem info;

  /// 索引
  final int index;

  /// 当前选中的
  final dynamic selectedIcon;

  /// 点击回调
  final void Function(dynamic name) onTap;

  /// 选中元素颜色
  final Color selectedItemColor;

  /// 未选中元素颜色
  final Color unselectedItemColor;

  /// 图标 - 计算属性
  Widget get icon {
    return IconTheme(
      data: IconThemeData(
        color: selected ? selectedItemColor : unselectedItemColor,
        size: Adapt.px(50),
      ),
      child: info.icon,
    );
  }

  /// 图标 - 计算属性
  bool get selected {
    if (info.name != null) {
      return info.name == selectedIcon;
    }

    return index == selectedIcon;
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> list = [icon];
    if (info.label != null) {
      list.add(Padding(
        padding: EdgeInsets.only(top: Adapt.px(3)),
        child: Text(
          info.label!,
          style: TextStyle(
            fontSize: Adapt.px(18),
            fontWeight: FontWeight.w500,
            height: 1.4,
            color: selected ? selectedItemColor : unselectedItemColor,
          ),
        ),
      ));
    }

    return Expanded(
      child: InkWell(
        onTap: () {
          if (info.name != null) {
            onTap(info.name);
          } else {
            onTap(index);
          }
        },
        child: Padding(
          padding: EdgeInsets.symmetric(vertical: Adapt.px(8)),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            mainAxisAlignment: MainAxisAlignment.center,
            children: list,
          ),
        ),
      ),
    );
  }
}

/// navbar元素数据
class FcNavigationBarItem {
  const FcNavigationBarItem({
    this.name,
    required this.icon,
    this.label,
    Widget? activeIcon,
    this.backgroundColor,
  }) : activeIcon = activeIcon ?? icon;

  /// 唯一标识符
  final dynamic name;

  /// 图标
  final Widget icon;

  /// 标题
  final String? label;

  /// 活跃图标
  final Widget activeIcon;

  /// 背景色
  final Color? backgroundColor;
}
